import Model from '../models/Model';
declare class Collection<Item = unknown> {
    all: () => Item[];
    average: <K>(key?: K) => number;
    avg: <K>(key?: K) => number;
    chunk: (size: number) => Collection<Item[]>;
    collapse: () => Collection<Item>;
    combine: <T, U>(array: U[]) => Collection<T>;
    concat: <T>(collectionOrArrayOrObject: Collection<T> | T[] | object) => any;
    contains: <K, V>(key: K | Function, value?: V) => boolean;
    count: () => number;
    crossJoin: <T>(values: T[]) => Collection<[Item, T]>;
    dd: () => void;
    diff: <T>(values: T[] | Collection<Item>) => Collection<Item>;
    diffAssoc: <T>(values: T[] | Collection<T>) => Collection<Item>;
    diffKeys: <K extends keyof Item>(object: object) => Collection<K>;
    dump: () => this;
    each: (fn: (item: Item) => void) => this;
    every: (fn: (item: Item) => boolean) => boolean;
    except: <K>(properties: K[]) => Collection<Item>;
    filter: (fn: (item: Item, key?: any) => boolean) => Collection<Item>;
    first: <V>(fn?: (item: Item) => boolean, defaultValue?: (...any: any[]) => V | Item) => Item;
    flatMap: <T>(fn: (item: Item, key: any) => T) => Collection<T>;
    flatten: (depth?: number) => Collection<Item>;
    flip: () => Collection<Item>;
    forget: <K>(key: K) => this;
    forPage: (page: number, chunk: number) => Collection<Item>;
    get: <K, V>(key: K, defaultValue?: (...any: any[]) => V | Item) => Item | null;
    groupBy: <T, K>(key: ((item: Item, index?: number) => K) | K) => Collection<T>;
    has: <K>(key: K | Item[]) => boolean;
    implode: <K>(key: K, glue?: string) => string;
    intersect: (values: Item[] | Collection<Item>) => Collection<Item>;
    intersectByKeys: <K extends keyof Item>(values: Item | Collection<Item>) => Collection<K>;
    isEmpty: () => boolean;
    isNotEmpty: () => boolean;
    keyBy: <T, K>(key: K | Function) => Collection<T>;
    keys: () => Collection<string>;
    last: (fn?: (item: Item) => boolean) => Item;
    macro: (name: string, fn: Function) => void;
    map: <T>(fn: (item: Item, index: any) => T) => Collection<T>;
    mapInto: <T extends Function>(ClassName: T) => Collection<T>;
    mapToGroups: (fn: Function) => Collection<any>;
    mapWithKeys: <T>(fn: Function) => Collection<T>;
    max: (key?: string) => number;
    median: <K>(key?: K) => Item;
    merge: <T>(objectOrArray: object | T[]) => Collection<T>;
    min: <K>(key?: K) => number;
    mode: <K>(key?: K) => Collection<Item> | null;
    nth: (n: number, offset?: number) => Collection<Item>;
    only: <K>(properties: K[]) => Collection<Item>;
    partition: (fn: (item: Item) => boolean) => [Item[], Item[]];
    pipe: <U>(fn: (...any: any[]) => U) => U;
    pluck: <T, K, V>(value: V, key?: K) => Collection<T>;
    pop: () => Item;
    prepend: <K, V>(value: V, key?: K) => this;
    pull: <K>(key: K) => Item | null;
    push: (item: Item) => this;
    put: <K, V>(key: K, value: V) => this;
    random: (length?: number) => this | Item;
    reduce: <T>(fn: (_carry: T | null, item: Item) => T, carry?: T) => any;
    reject: (fn: (item: Item) => boolean) => Collection<Item>;
    reverse: () => Collection<Item>;
    search: (valueOrFunction: Item | ((value: Item, key: number) => boolean), strict: boolean) => any;
    shift: () => Item;
    shuffle: () => this;
    slice: (remove: number, limit?: number) => Collection<Item>;
    sort: (fn?: (a: Item, b: Item) => number) => Collection<Item>;
    sortBy: <V>(value: V) => Collection<Item>;
    sortByDesc: <V>(value: V) => Collection<Item>;
    splice: (index: number, limit: number, replace?: Item[]) => Collection<Item>;
    split: (numberOfGroups: number) => Item[];
    sum: <K>(key?: K | ((item: Item) => number | string)) => number | string;
    [Symbol.iterator]: () => Iterator<Item>;
    take: (length: number) => Collection<Item>;
    tap: (fn: (collection: Collection<Item>) => void) => this;
    times: <T>(times: number, fn: (time: number) => T) => T[];
    toArray: <T>() => T[];
    toJson: () => string;
    transform: <T>(fn: (item: Item) => T) => Collection<T>;
    union: <T>(object: Object) => Collection<T>;
    unique: <K>(key?: K | Function) => Collection<Item>;
    unless: (value: boolean, fn: (this: any) => any, defaultFn: (this: any) => any) => void;
    unwrap: <T>(value: T[] | Collection<T>) => T[];
    values: <T>() => Collection<T>;
    when: (condition: boolean, fn: (this: any) => any, defaultFn: (this: any) => any) => void;
    where: <K, V>(key: K, value: V) => Collection<Item>;
    whereIn: <K, V>(key: K, values: V[]) => Collection<Item>;
    whereNotIn: <K, V>(key: K, values: V[]) => Collection<Item>;
    wrap: <T>(value: T | T[] | Collection<T>) => Collection<T>;
    zip: <T>(array: T[]) => Collection<[Item, T]>;
    collection: Collection<Item>;
    constructor(items?: Item[] | Model);
    static __get(target: any, prop: any): any;
    static fromArray(array: any, skipEmpty?: boolean): Collection<unknown>;
}
export default Collection;
