import { performSafeRequestREST, performSafeRequestGraphql } from '../utils';
import Collection from './Collection';
import { KeyValueUnknown, ResolvingRESTOptions } from '../typings';
import EventEmitter from '../EventEmitter';
import { DocumentNode } from 'graphql';
export default abstract class Model extends EventEmitter {
    id: string;
    uuid: string;
    loading: boolean;
    children: unknown;
    createMutation?: string | Function | DocumentNode;
    updateMutation?: string | Function | DocumentNode;
    deleteMutation?: string | Function | DocumentNode;
    protected submittableProps: any[];
    protected __typename: string | undefined;
    protected performSafeRequestGraphql: typeof performSafeRequestGraphql;
    protected performSafeRequestREST: typeof performSafeRequestREST;
    private _exists;
    constructor(props?: {});
    get doRequest(): typeof performSafeRequestGraphql | typeof performSafeRequestREST;
    get className(): string;
    get displayClassName(): string;
    get defaultMethod(): string;
    exists(): boolean;
    protected defaults(): KeyValueUnknown;
    protected hydrate(item: any): any;
    protected getMethod(_opts: ResolvingRESTOptions): any;
    toCollection(skipEmpty?: boolean): Collection<unknown>;
    toArray(skipEmpty?: boolean): unknown[];
    getClassName(): string;
    protected getInputFields(): string[];
    getUpdateVariables(): any;
    toSubmittable(props?: any[]): unknown;
    save(): Promise<any>;
    create(params?: unknown, mutation?: string | DocumentNode): Promise<any>;
    update(params?: unknown, mutation?: string | DocumentNode): Promise<any>;
    delete(params?: unknown, mutation?: string | DocumentNode): Promise<any>;
    mutate(mutationOrUrl: any, params: any, method?: string): Promise<any>;
    clone(): this;
    markExists(): this;
    markNotExists(): this;
    protected beforeMutate(): Promise<this>;
    protected afterMutate(): this;
    protected resolveRequest(request: string | DocumentNode, defaultRequest: string | Function | DocumentNode): string | DocumentNode;
    protected resolveParams(params: Object): Object;
}
