import { DocumentNode } from 'graphql';
import Collection from '../models/Collection';
import { performSafeRequestREST, performSafeRequestGraphql } from '../utils';
import EventEmitter from '../EventEmitter';
import { GraphQLErrorBag, KeyValueString, PropertyFunction, ResolvingRESTOptions, UrlResolver, HttpMethod, KeyValueUnknown } from '../typings';
export default abstract class Repository<M = unknown> extends EventEmitter {
    private _exists;
    protected performSafeRequestGraphql: typeof performSafeRequestGraphql;
    protected performSafeRequestREST: typeof performSafeRequestREST;
    loading: boolean;
    lastError: Error | GraphQLErrorBag;
    method: string;
    dataset: Collection<M>;
    queryParams: KeyValueUnknown;
    subscriptions(): unknown[];
    model: M | unknown;
    abstract fetchOneQuery: string | PropertyFunction<string>;
    abstract fetchManyQuery: string | PropertyFunction<string>;
    protected constructor(array?: Collection<M> | M[]);
    get className(): string;
    get displayClassName(): string;
    get defaultMethod(): "get" | "post";
    exists(): boolean;
    getMethod(opts: ResolvingRESTOptions): string;
    fromArray(array: unknown[], skipEmpty?: boolean): Collection<M>;
    static fromArray(array: unknown[], skipEmpty?: boolean): any;
    protected onError(e: Error | GraphQLErrorBag): void;
    query(queryOrUrl: string | UrlResolver | DocumentNode, params?: KeyValueString, collection?: boolean, method?: HttpMethod): Promise<any>;
    beforeQuery(): Promise<void>;
    processResponse(collection: any, data: any): Promise<any>;
    afterQuery(): Promise<void>;
    many(params?: any): Promise<Collection<M>>;
    one(id: any): Promise<any>;
    static one(params: any): any;
}
